Index: Singular/janet.cc
===================================================================
--- Singular/janet.cc	(revision a74143eec598021f060c389b66230f8f035cc1c5)
+++ Singular/janet.cc	(revision 31f1850ad6697d9acd155b53fa63f9e1a648ed9c)
@@ -44,5 +44,5 @@
 
 //#define pow_(x) pTotaldegree((x))
-//#define pow_(x) pDeg((x))
+//#define pow_(x) p_Deg((x,currRing))
 pFDegProc jDeg;
 #define pow_(x) jDeg((x),currRing)
@@ -957,5 +957,5 @@
   {
     degree_compatible=1;
-    jDeg=pDeg;
+    jDeg=p_Deg;
     ListGreatMove=ListGreatMoveDegree;
   }
Index: Singular/wrapper.cc
===================================================================
--- Singular/wrapper.cc	(revision a74143eec598021f060c389b66230f8f035cc1c5)
+++ Singular/wrapper.cc	(revision 31f1850ad6697d9acd155b53fa63f9e1a648ed9c)
@@ -89,5 +89,5 @@
       {
         //if (pTotaldegree(iT->info->lead) == pTotaldegree(iT->info->history))
-        if (pDeg(iT->info->lead) == pDeg(iT->info->history))
+        if (p_Deg(iT->info->lead,currRing) == p_Deg(iT->info->history,currRing))
         {
           result->m[ideal_length-ideal_index-1]=pCopy(iT->info->root);
Index: kernel/fast_maps.cc
===================================================================
--- kernel/fast_maps.cc	(revision a74143eec598021f060c389b66230f8f035cc1c5)
+++ kernel/fast_maps.cc	(revision 31f1850ad6697d9acd155b53fa63f9e1a648ed9c)
@@ -638,5 +638,5 @@
   poly fq_p=NULL;
   choice=NULL;
-  while ((iter != NULL) && (pDeg(iter->src, r) > ggt_deg))
+  while ((iter != NULL) && (p_Deg(iter->src, r) > ggt_deg))
   {
     //    maMonomial_Out(iter, r, NULL);
@@ -648,5 +648,5 @@
       int tmp_deg;
       assume((q1!=NULL)&&(q2!=NULL));
-      if ((tmp_deg=pDeg(q,r)) > ggt_deg)
+      if ((tmp_deg=p_Deg(q,r)) > ggt_deg)
       {
         choice=iter;
@@ -657,5 +657,5 @@
           p_LmFree(fq_p, r);
         }
-        ggt_deg = tmp_deg ; /*pDeg(q, r);*/
+        ggt_deg = tmp_deg ; /*p_Deg(q, r);*/
         ggT = q;
         fp_p = q1;
Index: kernel/ideals.cc
===================================================================
--- kernel/ideals.cc	(revision a74143eec598021f060c389b66230f8f035cc1c5)
+++ kernel/ideals.cc	(revision 31f1850ad6697d9acd155b53fa63f9e1a648ed9c)
@@ -1224,5 +1224,5 @@
   for(i=IDELEMS(Q)-1;i>=0;i--)
     if(w==NULL)
-      N=si_max(N,pDeg(Q->m[i]));
+      N=si_max(N,p_Deg(Q->m[i],currRing));
     else
       N=si_max(N,pDegW(Q->m[i],w));
@@ -1251,5 +1251,5 @@
           p=pJetW(pSub(p,ppMult_mm(Q->m[j],p0)),N,w);
         pNormalize(p);
-        if((w==NULL)&&(pDeg(p0)>n)||(w!=NULL)&&(pDegW(p0,w)>n))
+        if((w==NULL)&&(p_Deg(p0,currRing)>n)||(w!=NULL)&&(pDegW(p0,w)>n))
           p_Delete(&p0,currRing);
         else
@@ -1264,5 +1264,5 @@
           pIter(p);
           pNext(p0)=NULL;
-          if(((w==NULL)&&(pDeg(p0)>n))
+          if(((w==NULL)&&(p_Deg(p0,currRing)>n))
           ||((w!=NULL)&&(pDegW(p0,w)>n)))
             p_Delete(&p0,currRing);
@@ -2133,5 +2133,5 @@
       if (p!=NULL)
       {
-        d = pDeg(p);
+        d = p_Deg(p,currRing);
         k= pGetComp(p);
         if (slength>0) k--;
Index: kernel/linearAlgebra.cc
===================================================================
--- kernel/linearAlgebra.cc	(revision a74143eec598021f060c389b66230f8f035cc1c5)
+++ kernel/linearAlgebra.cc	(revision 31f1850ad6697d9acd155b53fa63f9e1a648ed9c)
@@ -1212,6 +1212,6 @@
                    const poly f0, const poly g0, const int d, poly &f, poly &g)
 {
-  int n = (int)pDeg(f0);
-  int m = (int)pDeg(g0);
+  int n = (int)p_Deg(f0,currRing);
+  int m = (int)p_Deg(g0,currRing);
   matrix aMat = mpNew(n + m, n + m);     /* matrix A for linear system */
   matrix pMat; matrix lMat; matrix uMat; /* for the decomposition of A */
Index: kernel/polys.h
===================================================================
--- kernel/polys.h	(revision a74143eec598021f060c389b66230f8f035cc1c5)
+++ kernel/polys.h	(revision 31f1850ad6697d9acd155b53fa63f9e1a648ed9c)
@@ -247,5 +247,4 @@
  ***************************************************************/
 inline int pWeight(int i, const ring R = currRing){ return p_Weight(i, R); }
-inline long pDeg(poly p, const ring R = currRing) { return p_Deg(p, R); }
  
 

Index: kernel/kutil.cc
===================================================================
--- kernel/kutil.cc	(revision a74143eec598021f060c389b66230f8f035cc1c5)
+++ kernel/kutil.cc	(revision 31f1850ad6697d9acd155b53fa63f9e1a648ed9c)
@@ -3238,6 +3238,6 @@
   )
   {
-    int o=pDeg(p);
-    int oo=pDeg(set[length]);
+    int o=p_Deg(p,currRing);
+    int oo=p_Deg(set[length],currRing);
 
     if ((oo<o)
@@ -3249,5 +3249,5 @@
       if (an >= en-1)
       {
-        if ((pDeg(set[an])>=o) && (pLmCmp(set[an],p) == cmp_int))
+        if ((p_Deg(set[an],currRing)>=o) && (pLmCmp(set[an],p) == cmp_int))
         {
           return an;
@@ -3256,5 +3256,5 @@
       }
       i=(an+en) / 2;
-      if ((pDeg(set[i])>=o) && (pLmCmp(set[i],p) == cmp_int)) en=i;
+      if ((p_Deg(set[i],currRing)>=o) && (pLmCmp(set[i],p) == cmp_int)) en=i;
       else                              an=i;
     }
@@ -6342,10 +6342,10 @@
   strat->overflow=FALSE;
   ring new_tailRing = rModifyRing(currRing,
                                   // Hmmm .. the condition pFDeg == pDeg
                                   // might be too strong
 #ifdef HAVE_RINGS
-                                  (strat->homog && currRing->pFDeg == pDeg && !(rField_is_Ring(currRing))), // TODO Oliver
+                                  (strat->homog && currRing->pFDeg == p_Deg && !(rField_is_Ring(currRing))), // TODO Oliver
 #else
-                                  (strat->homog && pFDeg == pDeg), // omit_degree
+                                  (strat->homog && currRing->pFDeg == p_Deg), // omit_degree
 #endif
                                   (strat->ak==0), // omit_comp if the input is an ideal
@@ -6752,5 +6752,14 @@
     else if (strat->tailRing->pLDeg==maxdegreeWecart) PrintS("maxdegreeWecart");
     else Print("? (%lx)", (long)strat->tailRing->pLDeg);
-    Print(" syzring:%d, syzComp(strat):%d syzComb:%d limit:%ld\n",rIsSyzIndexRing(currRing),strat->syzComp,rGetCurrSyzLimit(currRing));
+    PrintLn();
+  PrintS("currRing->pFDeg: ");
+    if (currRing->pFDeg==p_Totaldegree) PrintS("p_Totaldegree");
+    else if (currRing->pFDeg==p_WFirstTotalDegree) PrintS("pWFirstTotalDegree");
+    else if (currRing->pFDeg==p_Deg) PrintS("p_Deg");
+    else if (currRing->pFDeg==kHomModDeg) PrintS("kHomModDeg");
+    else if (currRing->pFDeg==totaldegreeWecart) PrintS("totaldegreeWecart");
+    else Print("? (%lx)", (long)currRing->pFDeg);
+    PrintLn();
+    Print(" syzring:%d, syzComp(strat):%d limit:%d\n",rIsSyzIndexRing(currRing),strat->syzComp,rGetCurrSyzLimit(currRing));
     if(TEST_OPT_DEGBOUND)
       Print(" degBound: %d\n", Kstd1_deg);
@@ -6342,10 +6342,10 @@
   strat->overflow=FALSE;
   ring new_tailRing = rModifyRing(currRing,
-                                  // Hmmm .. the condition pFDeg == pDeg
+                                  // Hmmm .. the condition pFDeg == p_Deg
                                   // might be too strong
 #ifdef HAVE_RINGS